@@ -10,7 +10,7 @@ impl Password {
         let mut watchdog: usize = constants::MAX_CONVERGENCE_ITERATIONS;
         loop {
             let length: usize = config
-                .cli_args
+                .args
                 .value_of("length")
                 .unwrap_or(&constants::DEFAULT_PASS_LEN.to_string())
                 .parse()
@@ -51,11 +51,9 @@ impl Password {
     }
     fn validate_special_chars(config: &Configurator, pass: &str) -> Result<(), ValidateError> {
         for e in constants::SPECIAL_CHARS.to_vec().iter() {
-            if config.cli_args.is_present("no_special_chars") && pass.contains(&e.to_string()) {
+            if config.args.is_present("no_special_chars") && pass.contains(&e.to_string()) {
                 return Err(ValidateError::NoSpecialChars);
-            } else if !config.cli_args.is_present("no_special_chars")
-                && pass.contains(&e.to_string())
-            {
+            } else if !config.args.is_present("no_special_chars") && pass.contains(&e.to_string()) {
                 return Ok(());
             }
         }
@@ -65,9 +63,9 @@ impl Password {
     fn validate_uppercase(config: &Configurator, pass: &str) -> Result<(), ValidateError> {
         for e in 'A' as u8..'Z' as u8 + 1 {
             let c = e as char;
-            if config.cli_args.is_present("no_uppercase") && pass.contains(&c.to_string()) {
+            if config.args.is_present("no_uppercase") && pass.contains(&c.to_string()) {
                 return Err(ValidateError::NoUpperCase);
-            } else if !config.cli_args.is_present("no_uppercase") && pass.contains(&c.to_string()) {
+            } else if !config.args.is_present("no_uppercase") && pass.contains(&c.to_string()) {
                 return Ok(());
             }
         }
@@ -76,9 +74,9 @@ impl Password {
     fn validate_lowercase(config: &Configurator, pass: &str) -> Result<(), ValidateError> {
         for e in 'a' as u8..'z' as u8 + 1 {
             let c = e as char;
-            if config.cli_args.is_present("no_lowercase") && pass.contains(&c.to_string()) {
+            if config.args.is_present("no_lowercase") && pass.contains(&c.to_string()) {
                 return Err(ValidateError::NoLowerCase);
-            } else if !config.cli_args.is_present("no_lowercase") && pass.contains(&c.to_string()) {
+            } else if !config.args.is_present("no_lowercase") && pass.contains(&c.to_string()) {
                 return Ok(());
             }
         }
@@ -87,9 +85,9 @@ impl Password {
     fn validate_numbers(config: &Configurator, pass: &str) -> Result<(), ValidateError> {
         for e in '0' as u8..'9' as u8 + 1 {
             let c = e as char;
-            if config.cli_args.is_present("no_numbers") && pass.contains(&c.to_string()) {
+            if config.args.is_present("no_numbers") && pass.contains(&c.to_string()) {
                 return Err(ValidateError::NoNumbers);
-            } else if !config.cli_args.is_present("no_numbers") && pass.contains(&c.to_string()) {
+            } else if !config.args.is_present("no_numbers") && pass.contains(&c.to_string()) {
                 return Ok(());
             }
         }
@@ -101,6 +99,44 @@ impl Password {
 #[cfg(test)]
 mod tests {
     use super::*;
+
+    fn matches_from(arg_vec: Vec<&str>) -> clap::ArgMatches {
+        use clap::{App, Arg};
+        let args = App::new("randompass")
+            .arg(
+                Arg::new("length")
+                    .long("length")
+                    .short('l')
+                    .help("Password length."),
+            )
+            .arg(
+                Arg::new("no_lowercase")
+                    .long("no_lowercase")
+                    .short('o')
+                    .help("Disable usage of lowercase letters."),
+            )
+            .arg(
+                Arg::new("no_numbers")
+                    .long("no_numbers")
+                    .short('n')
+                    .help("Disable usage of numbers."),
+            )
+            .arg(
+                Arg::new("no_special_chars")
+                    .long("no_special_chars")
+                    .short('c')
+                    .help("Disable usage of special characters (i.e.: !, $, #)."),
+            )
+            .arg(
+                Arg::new("no_uppercase")
+                    .long("no_uppercase")
+                    .short('u')
+                    .help("Disable usage of uppercase letters."),
+            )
+            .get_matches_from(arg_vec);
+        args
+    }
+
     macro_rules! assert_err {
         ($expression:expr, $($pattern:tt)+) => {
             match $expression {
@@ -112,10 +148,8 @@ mod tests {
 
     #[test]
     fn test_pass_generate_works_when_typical() {
-        use clap::App;
-        let arg_vec = vec!["randompass"];
-        let cli_args = App::new("randompass").get_matches_from(arg_vec);
-        let config = Configurator { cli_args };
+        let args = matches_from(vec!["randompass"]);
+        let config = Configurator { args };
 
         let actual = Password::generate(&config, Alphabet::new(&config));
 
@@ -125,16 +159,8 @@ mod tests {
 
     #[test]
     fn test_pass_generate_works_when_no_special_characters() {
-        use clap::{App, Arg};
-        let arg_vec = vec!["randompass", "-c"];
-        let cli_args = App::new("randompass")
-            .arg(
-                Arg::with_name("no_special_chars")
-                    .short("c")
-                    .long("no_special_chars"),
-            )
-            .get_matches_from(arg_vec);
-        let config = Configurator { cli_args };
+        let args = matches_from(vec!["randompass", "-c"]);
+        let config = Configurator { args };
 
         let actual = Password::generate(&config, Alphabet::new(&config));
 
@@ -143,16 +169,8 @@ mod tests {
 
     #[test]
     fn test_pass_generate_fails_when_special_characters_but_none_requested() {
-        use clap::{App, Arg};
-        let arg_vec = vec!["randompass", "-c"];
-        let cli_args = App::new("randompass")
-            .arg(
-                Arg::with_name("no_special_chars")
-                    .short("c")
-                    .long("no_special_chars"),
-            )
-            .get_matches_from(arg_vec);
-        let config = Configurator { cli_args };
+        let args = matches_from(vec!["randompass", "-c"]);
+        let config = Configurator { args };
 
         let actual = "#$!".to_string();
 
@@ -164,16 +182,8 @@ mod tests {
 
     #[test]
     fn test_pass_generate_works_when_no_lowercase() {
-        use clap::{App, Arg};
-        let arg_vec = vec!["randompass", "-o"];
-        let cli_args = App::new("randompass")
-            .arg(
-                Arg::with_name("no_lowercase")
-                    .short("o")
-                    .long("no_lowercase"),
-            )
-            .get_matches_from(arg_vec);
-        let config = Configurator { cli_args };
+        let args = matches_from(vec!["randompass", "-o"]);
+        let config = Configurator { args };
 
         let actual = Password::generate(&config, Alphabet::new(&config));
 
@@ -182,16 +192,8 @@ mod tests {
 
     #[test]
     fn test_pass_generate_fails_when_lowercase_but_none_requested() {
-        use clap::{App, Arg};
-        let arg_vec = vec!["randompass", "-o"];
-        let cli_args = App::new("randompass")
-            .arg(
-                Arg::with_name("no_lowercase")
-                    .short("o")
-                    .long("no_lowercase"),
-            )
-            .get_matches_from(arg_vec);
-        let config = Configurator { cli_args };
+        let args = matches_from(vec!["randompass", "-o"]);
+        let config = Configurator { args };
 
         let actual = "abc".to_string();
 
@@ -203,16 +205,8 @@ mod tests {
 
     #[test]
     fn test_pass_generate_works_when_no_uppercase() {
-        use clap::{App, Arg};
-        let arg_vec = vec!["randompass", "-u"];
-        let cli_args = App::new("randompass")
-            .arg(
-                Arg::with_name("no_uppercase")
-                    .short("u")
-                    .long("no_uppercase"),
-            )
-            .get_matches_from(arg_vec);
-        let config = Configurator { cli_args };
+        let args = matches_from(vec!["randompass", "-u"]);
+        let config = Configurator { args };
 
         let actual = Password::generate(&config, Alphabet::new(&config));
 
@@ -221,16 +215,8 @@ mod tests {
 
     #[test]
     fn test_pass_generate_fails_when_uppercase_but_none_requested() {
-        use clap::{App, Arg};
-        let arg_vec = vec!["randompass", "-u"];
-        let cli_args = App::new("randompass")
-            .arg(
-                Arg::with_name("no_uppercase")
-                    .short("u")
-                    .long("no_uppercase"),
-            )
-            .get_matches_from(arg_vec);
-        let config = Configurator { cli_args };
+        let args = matches_from(vec!["randompass", "-u"]);
+        let config = Configurator { args };
 
         let actual = "ABC".to_string();
 
@@ -242,12 +228,8 @@ mod tests {
 
     #[test]
     fn test_pass_generate_works_when_no_numbers() {
-        use clap::{App, Arg};
-        let arg_vec = vec!["randompass", "-n"];
-        let cli_args = App::new("randompass")
-            .arg(Arg::with_name("no_numbers").short("n").long("no_numbers"))
-            .get_matches_from(arg_vec);
-        let config = Configurator { cli_args };
+        let args = matches_from(vec!["randompass", "-n"]);
+        let config = Configurator { args };
 
         let actual = Password::generate(&config, Alphabet::new(&config));
 
@@ -256,12 +238,8 @@ mod tests {
 
     #[test]
     fn test_pass_generate_fails_when_numbers_but_none_requested() {
-        use clap::{App, Arg};
-        let arg_vec = vec!["randompass", "-n"];
-        let cli_args = App::new("randompass")
-            .arg(Arg::with_name("no_numbers").short("n").long("no_numbers"))
-            .get_matches_from(arg_vec);
-        let config = Configurator { cli_args };
+        let args = matches_from(vec!["randompass", "-n"]);
+        let config = Configurator { args };
 
         let actual = "123".to_string();
 
@@ -273,31 +251,12 @@ mod tests {
 
     #[test]
     fn test_pass_generate_fails_when_impossible_constraints() {
-        use clap::{App, Arg};
         use rand::distributions::Uniform;
         use rand::rngs::StdRng;
         use rand::SeedableRng;
 
-        let arg_vec = vec!["randompass", "-c", "-u", "-o", "-n"];
-        let cli_args = App::new("randompass")
-            .arg(
-                Arg::with_name("no_special_chars")
-                    .short("c")
-                    .long("no_special_chars"),
-            )
-            .arg(
-                Arg::with_name("no_uppercase")
-                    .short("u")
-                    .long("no_uppercase"),
-            )
-            .arg(
-                Arg::with_name("no_lowercase")
-                    .short("o")
-                    .long("no_lowercase"),
-            )
-            .arg(Arg::with_name("no_numbers").short("n").long("no_numbers"))
-            .get_matches_from(arg_vec);
-        let config = Configurator { cli_args };
+        let args = matches_from(vec!["randompass", "-c", "-u", "-o", "-n"]);
+        let config = Configurator { args };
         let chars: Vec<char> = vec!['a'];
         let alphabet = Alphabet {
             chars,
